@@ -33,3 +33,28 @@ sub download {
 
 __PACKAGE__->meta->make_immutable;
 1;
+
+__END__
+
+=head1 NAME
+
+CPAN::Packager::Downloader - Download cpan module tarball from CPAN
+
+=head1 SYNOPSIS
+
+
+=head1 DESCRIPTION
+
+
+=head1 AUTHOR
+
+Takatoshi Kitano E<lt>kitano.tk@gmail.comE<gt>
+
+=head1 SEE ALSO
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
